﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DailyPlanner
{
    /// <summary>
    /// Логика взаимодействия для AddTaskPage.xaml
    /// </summary>
    public partial class AddTaskPage : Page
    {
        public int UserID { get; set; }
        string FilePath = string.Empty;
        public AddTaskPage(int iduser)
        {
            InitializeComponent();
            UserID = iduser;
            CmbMainTask.ItemsSource = DB.db.Task.Where(item => item.IDUser == UserID && item.IDMainTask == null).ToList();
            CmbMainTask.DisplayMemberPath = "NameTask";
            CmbMainTask.SelectedValuePath = "TaskID";
            CmbMainTask.SelectedIndex = 0;
        }

        private void SubTask_Checked(object sender, RoutedEventArgs e)
        {
            MainTask.Visibility = Visibility.Visible;
        }

        private void SubTask_Unchecked(object sender, RoutedEventArgs e)
        {
            MainTask.Visibility = Visibility.Collapsed;
        }

        private void ImageGrid_MouseDown(object sender, MouseButtonEventArgs e)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();
            if (openFileDialog.ShowDialog() == true)
            {
                FilePath = openFileDialog.FileName;
                string uriString = $"{FilePath}";
                TxtAddImage.Visibility = Visibility.Hidden;
                PhotoOfClent.Source = new BitmapImage(new Uri(@uriString));
            }
            else
            {
                FilePath = string.Empty;
            }
        }

        private void BtnDeletePhoto_Click(object sender, RoutedEventArgs e)
        {
            PhotoOfClent.Source = null;
            TxtAddImage.Visibility = Visibility.Visible;
            FilePath = string.Empty;
        }

        public bool AddTask(string NameTask, int IDUser, int? IDMainTask, DateTime? DateOfTask, TimeSpan? TimeOfTask, string Description, byte[] Image)
        {
            if (NameTask == string.Empty)
            {
                MessageBox.Show("Задача должна содержать как минимум название");
                return false;
            }
            else
            {
                try
                {
                    Task NewTask = new Task();
                    NewTask.NameTask = NameTask;
                    NewTask.IDUser = IDUser;
                    NewTask.IDMainTask = IDMainTask;
                    NewTask.DateOfTask = DateOfTask;
                    NewTask.TimeOfTask = TimeOfTask;
                    NewTask.Description = Description;
                    NewTask.Image = Image;
                    DB.db.Task.Add(NewTask);
                    DB.db.SaveChanges();
                    MessageBox.Show("Добавлено");
                    CmbMainTask.ItemsSource = DB.db.Task.Where(item => item.IDUser == UserID && item.IDMainTask == null).ToList();
                    CmbMainTask.DisplayMemberPath = "NameTask";
                    CmbMainTask.SelectedValuePath = "TaskID";
                    CmbMainTask.SelectedIndex = 0;
                    return true;
                }
                catch
                {
                    MessageBox.Show("Не корректные данные");
                    return false;
                }

            }
        }
        private void BtnAddTask_Click(object sender, RoutedEventArgs e)
        {
            int? IDMainTask = null;
            if (SubTask.IsChecked == true)
            {
                IDMainTask =Convert.ToInt32(CmbMainTask.SelectedValue.ToString());
            }
            string Description = null;
            if (TxtDescription.Text != string.Empty)
            {
                Description = TxtDescription.Text;
            }
            byte[] Image = null;
            if (FilePath != string.Empty)
            {
                Image = ConvertImageToByte.ImageToByte(FilePath);
            }
            TimeSpan? TimeOfTask = null;
            TimeSpan TempTime;
            if(TxtTimeOfTask.Text != string.Empty)
            {
                if (TimeSpan.TryParse(TxtTimeOfTask.Text, out TempTime) == false)
                {
                    MessageBox.Show("Некорректно задано время");
                }
                else
                {
                    TimeOfTask = TempTime;
                    AddTask(TxtName.Text, UserID, IDMainTask, DaPDateOfTask.SelectedDate.GetValueOrDefault(), TimeOfTask, Description, Image);
                }
            }
            else
            {
                AddTask(TxtName.Text, UserID, IDMainTask, DaPDateOfTask.SelectedDate.GetValueOrDefault(), TimeOfTask, Description, Image);
            }
            


        }
    }
}
