﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace DailyPlanner
{
    /// <summary>
    /// Логика взаимодействия для ShowTaskPage.xaml
    /// </summary>
    public partial class ShowTaskPage : Page
    {
        public int UserID { get; set; }
        //Переменная, которая укзывает, что необходимо удалить только подзадачу
        public bool IsDeleteSubtask = false;
        //Список с возможными состояними выполнения задачи
        List<StringFormatState> StateList = new List<StringFormatState>();
        string DateOfISO8601 = string.Empty;
        string FilePath = string.Empty;
        public ShowTaskPage(int iduser)
        {
            InitializeComponent();
            UserID = iduser;
            ShowTask();
            //Отображение сообщения о актуальных или пропущенных задачах
            DateTime Yesterday = DateTime.Today.AddDays(-1);
            Task ActualTask = DB.db.Task.FirstOrDefault(item => item.DateOfTask == DateTime.Today && item.IDUser == UserID);
            Task MissedTask = DB.db.Task.FirstOrDefault(item => item.DateOfTask == Yesterday && item.IDUser == UserID && item.State != true);
            if(ActualTask!=null) 
            {
                MessageArea.Visibility = Visibility.Visible;
                TxtActualTask.Visibility = Visibility.Visible;
            }
            if (MissedTask !=null)
            {
                MessageArea.Visibility = Visibility.Visible;
                TxtMissedTask.Visibility = Visibility.Visible;
            }
            StateList.Add(new StringFormatState {StringState="Выполняется" , State = null});
            StateList.Add(new StringFormatState {StringState="Выполнена" , State = true});
            StateList.Add(new StringFormatState {StringState="Не выполнена" , State = false});
            CmbStateMainTask.ItemsSource = StateList;
            CmbStateMainTask.DisplayMemberPath = "StringState";
            CmbStateMainTask.SelectedValuePath = "State";
            
        }

        // Представление задач пользователя
        public void ShowTask()
        {
            if (OnlyCurrentTask.IsChecked == true)
            {
                ListMainTask.ItemsSource = DB.db.Task.Where(item => item.IDUser == UserID && item.IDMainTask == null && (item.DateOfTask>=DateTime.Today || (item.DateOfTask==null && item.State!=true)) && item.DateOfTask.ToString().Contains(DateOfISO8601)).ToList();
            }
            else
            {
                ListMainTask.ItemsSource = DB.db.Task.Where(item => item.IDUser == UserID && item.IDMainTask == null && item.DateOfTask.ToString().Contains(DateOfISO8601)).ToList();
            }

        }
        

        private void DateOfMainTask_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            var CurrentMainTask = (sender as DatePicker).DataContext as Task;
            CurrentMainTask.DateOfTask = (sender as DatePicker).SelectedDate.GetValueOrDefault();
            DB.db.SaveChanges();
        }

        private void DateOfSubTask_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            var CurrentSubTask = (sender as DatePicker).DataContext as Task;
            CurrentSubTask.DateOfTask = (sender as DatePicker).SelectedDate.GetValueOrDefault();
            DB.db.SaveChanges();
        }

        private void ListMainTask_CurrentCellChanged(object sender, EventArgs e)
        {
            DB.db.SaveChanges();
        }

        private void ListSubTask_CurrentCellChanged(object sender, EventArgs e)
        {
            DB.db.SaveChanges();
        }
        
        public bool DeleteTask(Task CurrentTask)
        {
            DB.db.Task.Remove(CurrentTask);
            DB.db.SaveChanges();
            return true;
        }

        private void ListSubTask_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Delete)
            {
                MessageBoxResult result = MessageBox.Show("Удалить?", "", MessageBoxButton.YesNo);
                if (result == MessageBoxResult.Yes)
                {
                    Task CurrentTask = (sender as DataGrid).SelectedItem as Task;
                    DeleteTask(CurrentTask);
                    ShowTask();
                    IsDeleteSubtask = true;
                }
            }
        }

        private void OnlyCurrentTask_Checked(object sender, RoutedEventArgs e)
        {
            ShowTask();
        }

        private void OnlyCurrentTask_Unchecked(object sender, RoutedEventArgs e)
        {
            ShowTask();
        }

        private void ListMainTask_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Delete && IsDeleteSubtask == false)
            {
                MessageBoxResult result = MessageBox.Show("Удалить?", "", MessageBoxButton.YesNo);
                if (result == MessageBoxResult.Yes)
                {
                    Task CurrentTask = (sender as DataGrid).SelectedItem as Task;
                    foreach(Task SubTask in CurrentTask.SubTask)
                    {
                        DeleteTask(SubTask);
                    }
                    DeleteTask(CurrentTask);
                    ShowTask();
                }
            }
            else
            {
                IsDeleteSubtask = false;
            }
        }
        //конвертация даты в международный формат
        private void DaPSearchTask_SelectedDateChanged(object sender, SelectionChangedEventArgs e)
        {
            if (DaPSearchTask.Text != string.Empty)
            {
                DateOfISO8601 = DateTime.SpecifyKind((DateTime)DaPSearchTask.SelectedDate, DateTimeKind.Utc).ToString("yyyy-MM-dd");
            }
            else
            {
                DateOfISO8601 = string.Empty;
            }
            ShowTask();
        }
        //Привязка данных comboBox для генерируемой таблицы с подзадачами
        private void ListSubTask_LoadingRow(object sender, DataGridRowEventArgs e)
        {
            var dataGrid = sender as DataGrid;
            var comboBox = dataGrid.FindName("CmbStateSubTask") as DataGridComboBoxColumn;
            comboBox.ItemsSource = StateList;
         }

        private void TxtImageTask_MouseDown(object sender, MouseButtonEventArgs e)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();
            if (openFileDialog.ShowDialog() == true)
            {
                FilePath = openFileDialog.FileName;
                Task СurrentTask = (sender as Grid).DataContext as Task;
                Task Task = DB.db.Task.Find(СurrentTask.TaskID);
                Task.Image = ConvertImageToByte.ImageToByte(FilePath);
                DB.db.SaveChanges();
                ShowTask();
            }
        }

        private void TxtImageOfSubTask_MouseDown(object sender, MouseButtonEventArgs e)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();
            if (openFileDialog.ShowDialog() == true)
            {
                FilePath = openFileDialog.FileName;
                var СurrentTask = (sender as Grid).DataContext as Task;
                Task Task = DB.db.Task.Find(СurrentTask.TaskID);
                Task.Image = ConvertImageToByte.ImageToByte(FilePath);
                DB.db.SaveChanges();
                ShowTask();
            }
        }
        //Отображение сообщения
        private void CloseMessage_Click(object sender, RoutedEventArgs e)
        {
            MessageArea.Visibility = Visibility.Collapsed;
        }
    }
}
